database_odlyzko_zeta: Table of zeros of the Riemann zeta function
==================================================================

Description
-----------

Table of zeros of the Riemann zeta function by Andrew Odlyzko.

This package contains the file 'zeros6' with the first 2,001,052 zeros
of the Riemann zeta function, accurate to within 4*10^(-9).
